==> qt-creator-opensource-src-4.11.1.zip: qt-creator-opensource-src-4.11.1/src/plugins/cpaster/pasteselectdialog.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ui_pasteselect.h"

#include <QList>

QT_FORWARD_DECLARE_CLASS(QPushButton)

namespace CodePaster {
class Protocol;

class PasteSelectDialog : public QDialog
{
    Q_OBJECT
public:
    explicit PasteSelectDialog(const QList<Protocol*> &protocols,
                               QWidget *parent = nullptr);
    ~PasteSelectDialog() override;

    QString pasteId() const;

    QString protocol() const;
    void setProtocol(const QString &);

    int protocolIndex() const;

private:
    void protocolChanged(int);
    void list();
    void listDone(const QString &name, const QStringList &items);

    const QList<Protocol*> m_protocols;

    Internal::Ui::PasteSelectDialog m_ui;
    QPushButton *m_refreshButton;
};

} // namespace CodePaster

==> qt-creator-opensource-src-8.0.1.zip: qt-creator-opensource-src-8.0.1/src/plugins/cpaster/pasteselectdialog.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "ui_pasteselect.h"

#include <QList>

QT_FORWARD_DECLARE_CLASS(QPushButton)

namespace CodePaster {
class Protocol;

class PasteSelectDialog : public QDialog
{
    Q_OBJECT
public:
    explicit PasteSelectDialog(const QList<Protocol*> &protocols,
                               QWidget *parent = nullptr);
    ~PasteSelectDialog() override;

    QString pasteId() const;

    int protocol() const;
    void setProtocol(const QString &);

private:
    QString protocolName() const;
    void protocolChanged(int);
    void list();
    void listDone(const QString &name, const QStringList &items);

    const QList<Protocol*> m_protocols;

    Internal::Ui::PasteSelectDialog m_ui;
    QPushButton *m_refreshButton;
};

} // namespace CodePaster
